@@ -11,7 +11,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decodes or the arguments are missing
     # @since v4.1.9
     my $class = shift;
     my $mhead = shift // return undef;
@@ -124,7 +124,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::EinsUndEins - bounce mail parser class for C<1&1>.
+Sisimai::Lhost::EinsUndEins - bounce mail decoder class for 1&1 L<https://www.1und1.de/>.
 
 =head1 SYNOPSIS
 
@@ -132,8 +132,8 @@ Sisimai::Lhost::EinsUndEins - bounce mail parser class for C<1&1>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::EinsUndEins parses a bounce email which created by C<1&1>. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::EinsUndEins> decodes a bounce email which created by 1&1 L<https://www.1und1.de/>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -145,8 +145,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
