@@ -7,9 +7,9 @@ use warnings;
 sub description { 'Sendmail Open Source: https://sendmail.org/' }
 sub inquire {
     # Decode bounce messages from Sendmail Open Source
-    # @param    [Hash] mhead    Message headers of a bounce email
-    # @param    [String] mbody  Message body of a bounce email
-    # @return   [Hash]          Bounce data list and message/rfc822 part
+    # @param    [Hash] mhead    Message headers of the bounce email
+    # @param    [String] mbody  Message body of the bounce email
+    # @return   [Hash]          The list of decoded bounces and a message/rfc822 part block
     # @return   [undef]         failed to decode or the arguments are missing
     # @see      https://www.proofpoint.com/us/products/email-protection/open-source-email-solution
     # @since v4.0.0
@@ -23,6 +23,7 @@ sub inquire {
     $match ||= 1 if index($mhead->{'subject'}, 'Warning: ')                  == 0;
     return undef unless $match > 0;
 
+    require Sisimai::RFC1123;
     require Sisimai::SMTP::Reply;
     require Sisimai::SMTP::Status;
     require Sisimai::SMTP::Command;
@@ -57,7 +58,7 @@ sub inquire {
         # Read error messages and delivery status lines from the head of the email to the previous
         # line of the beginning of the original message.
         unless( $readcursor ) {
-            # Beginning of the bounce message or message/delivery-status part
+            # Beginning of the bounce message or the message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
             next;
         }
@@ -69,7 +70,7 @@ sub inquire {
             next unless my $o = Sisimai::RFC1894->field($e);
             $v = $dscontents->[-1];
 
-            if( $o->[-1] eq 'addr' ) {
+            if( $o->[3] eq 'addr' ) {
                 # Final-Recipient: rfc822; kijitora@example.jp
                 # X-Actual-Recipient: rfc822; kijitora@example.co.jp
                 if( $o->[0] eq 'final-recipient' ) {
@@ -86,7 +87,7 @@ sub inquire {
                     # X-Actual-Recipient: rfc822; kijitora@example.co.jp
                     $v->{'alias'} = $o->[2];
                 }
-            } elsif( $o->[-1] eq 'code' ) {
+            } elsif( $o->[3] eq 'code' ) {
                 # Diagnostic-Code: SMTP; 550 5.1.1 <userunknown@example.jp>... User Unknown
                 $v->{'spec'} = $o->[1];
                 $v->{'diagnosis'} = $o->[2];
@@ -94,6 +95,7 @@ sub inquire {
             } else {
                 # Other DSN fields defined in RFC3464
                 next unless exists $fieldtable->{ $o->[0] };
+                next if $o->[3] eq "host" && Sisimai::RFC1123->is_internethost($o->[2]) == 0;
                 $v->{ $fieldtable->{ $o->[0] } } = $o->[2];
 
                 next unless $f == 1;
@@ -110,16 +112,16 @@ sub inquire {
             if( substr($e, 0, 1) ne ' ') {
                 # Other error messages
                 if( index($e, '>>> ') == 0 ) {
-                    # >>> DATA
-                    $thecommand = Sisimai::SMTP::Command->find($e);
+                    # >>> DATA (Client Command)
+                    $thecommand ||= Sisimai::SMTP::Command->find($e);
 
                 } elsif( index($e, '<<< ') == 0 ) {
-                    # <<< Response
+                    # <<< Response from the SMTP server
                     my $cv = substr($e, 4,);
                     push @$esmtpreply, $cv unless grep { $cv eq $_ } @$esmtpreply;
 
                 } else {
-                    # Detect SMTP session error or connection error
+                    # Detect an SMTP session error or a connection error
                     next if $sessionerr;
                     if( index($e, $startingof->{'error'}->[0]) == 0 ) {
                         # ----- Transcript of session follows -----
@@ -147,7 +149,7 @@ sub inquire {
                             $anotherset->{'status'}     = $cs;
                             $anotherset->{'diagnosis'} .= ' '.$e;
 
-                        } elsif( index($e, 'Message: ') == 0 || index($e, 'Warning: ') == 0 ) {
+                        } elsif( index($e, 'Message ') == 0 || index($e, 'Warning: ') == 0 ) {
                             # Message could not be delivered for too long
                             # Warning: message still undelivered after 4 hours
                             $anotherset->{'diagnosis'} .= ' '.$e;
@@ -247,7 +249,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
